==> nextcloud-15.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/sr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информације о процесору нису доступне",
    "Load average" : "Просечно оптерећење",
    "Last minute" : "Последњи минут",
    "Memory info not available" : "Информације о меморији нису доступне",
    "Total" : "Укупно",
    "Current usage" : "Тренутна употреба",
    "Users" : "Корисника",
    "Groups" : "Група",
    "Links" : "Веза",
    "Mails" : "Поруке е-поште",
    "Federated sent" : "Послатих здружавања",
    "Federated received" : "Примљених здружавања",
    "Talk conversations" : "Talk разговори",
    "Last 24 hours" : "Последња 24 сата",
    "Last 1 hour" : "Последњих 1 сат",
    "Last 5 mins" : "Последњих 5 минута",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано! ",
    "Press ⌘-C to copy." : "Притисните ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "Monitoring" : "Праћење система",
    "Monitoring app with useful server information" : "Апликација праћења система са корисним серверским информацијама",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Даје корисне информације о серверу, као што су оптерећење процесора, употреба RAM-а, употреба диска, број корисника, итд.",
    "CPU load" : "Оптерећење процесора",
    "Memory usage" : "Употреба меморије",
    "Active users" : "Активних корисника",
    "Shares" : "Дељења",
    "Storage" : "Складиште",
    "Users:" : "Корисника:",
    "Files:" : "Фајлова:",
    "Storages:" : "Складишта:",
    "Free Space:" : "Слободно место:",
    "Nextcloud" : "Некстклауд",
    "Version:" : "Верзија:",
    "Apps installed:" : "Инсталиране апликације:",
    "Apps updates available:" : "Доступних ажурирања апликација:",
    "PHP" : "PHP",
    "Memory Limit:" : "Меморијски лимит:",
    "Max Execution Time:" : "Максимално време извршавања:",
    "Upload max size:" : "Максимална величина отпремања:",
    "Database" : "База података",
    "Type:" : "Тип:",
    "Size:" : "Величина:",
    "External monitoring tool" : "Спољни алати за праћење система",
    "You can connect an external monitoring tool by using this end point:" : "Можете повезати спољни алат за праћење система користећи следећу тачку повезивања:",
    "Did you know?" : "Да ли сте знали?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Ако додате \"?format=json\" на крај адресе, добићете резултате у JSON формату!"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/sr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информације о процесору нису доступне",
    "Load average" : "Просечно оптерећење",
    "Last minute" : "Последњи минут",
    "Memory info not available" : "Информације о меморији нису доступне",
    "Total" : "Укупно",
    "Current usage" : "Тренутна употреба",
    "Users" : "Корисника",
    "Groups" : "Група",
    "Links" : "Веза",
    "Mails" : "Поруке е-поште",
    "Federated sent" : "Послатих здружавања",
    "Federated received" : "Примљених здружавања",
    "Talk conversations" : "Talk разговори",
    "24 hours" : "24 сата",
    "1 hour" : "1 сат",
    "5 mins" : "5 минута",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано! ",
    "Press ⌘-C to copy." : "Притисните ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "System" : "Систем",
    "Monitoring" : "Праћење система",
    "Monitoring app with useful server information" : "Апликација праћења система са корисним серверским информацијама",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Даје корисне информације о серверу, као што су оптерећење процесора, употреба RAM-а, употреба диска, број корисника, итд.",
    "Operating System" : "Оперативни систем",
    "CPU" : "Процесор",
    "Memory" : "Меморија",
    "Server time" : "Време сервера",
    "Uptime" : "Време од стартовања система",
    "Time Servers" : "Сервери за време",
    "Load" : "Оптерећење",
    "Disk" : "Диск",
    "Mount" : "Монтирано",
    "Filesystem" : "Систем фајлова",
    "Size" : "Величина",
    "Available" : "Доступно",
    "Used" : "Искоришћено",
    "You will get a notification once one of your disks is nearly full." : "Добићете обавештење када су Вам дискови скоро пуни.",
    "Files:" : "Фајлова:",
    "Storages:" : "Складишта:",
    "Free Space:" : "Слободно место:",
    "Network" : "Мрежа",
    "Hostname" : "Име домаћина",
    "DNS" : "DNS",
    "Gateway" : "Мрежни пролаз",
    "Status" : "Статус",
    "Speed" : "Брзина",
    "MAC" : "MAC адреса",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Активних корисника",
    "Total users:" : "Укупно корисника:",
    "Shares" : "Дељења",
    "PHP" : "PHP",
    "Version:" : "Верзија:",
    "Memory Limit:" : "Меморијски лимит:",
    "Max Execution Time:" : "Максимално време извршавања:",
    "Upload max size:" : "Максимална величина отпремања:",
    "Database" : "База података",
    "Type:" : "Тип:",
    "Size:" : "Величина:",
    "External monitoring tool" : "Спољни алати за праћење система",
    "You can connect an external monitoring tool by using this end point:" : "Можете повезати спољни алат за праћење система користећи следећу тачку повезивања:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ако додате \"?format=json\" на крај адресе, добићете резултате у JSON формату.",
    "Last 24 hours" : "Последња 24 сата",
    "Last 1 hour" : "Последњих 1 сат",
    "Last 5 mins" : "Последњих 5 минута",
    "CPU load" : "Оптерећење процесора",
    "Memory usage" : "Употреба меморије",
    "Storage" : "Складиште",
    "Users:" : "Корисника:",
    "Nextcloud" : "Некстклауд",
    "Apps installed:" : "Инсталиране апликације:",
    "Apps updates available:" : "Доступних ажурирања апликација:",
    "Did you know?" : "Да ли сте знали?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Ако додате \"?format=json\" на крај адресе, добићете резултате у JSON формату!"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
